#
# spec file for package ghc-skylighting
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name skylighting
Name:           ghc-%{pkg_name}
Version:        0.8.3.4
Release:        lp152.1.1
Summary:        Syntax highlighting library
License:        GPL-2.0-or-later
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-skylighting-core-devel

%description
Skylighting is a syntax highlighting library with support for over one hundred
languages. It derives its tokenizers from XML syntax definitions used by KDE's
KSyntaxHighlighting framework, so any syntax supported by that framework can be
added. An optional command-line program is provided. Skylighting is intended to
be the successor to highlighting-kate. This package provides generated syntax
modules based on the KDE XML definitions provided by the 'skylighting-core'
package. As a result this package is licensed under the GPL.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%changelog
* Wed May  6 2020 psimons@suse.com
- Update skylighting to version 0.8.3.4.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-0.8.3.4/src/changelog.md
* Sat Jan 25 2020 psimons@suse.com
- Update skylighting to version 0.8.3.2.
  [#]# 0.8.3.2 -- 2020-01-21
  * This fixes a packaging error in 0.8.3.1, which didn't include
    the results of the bootsrap step and hence didn't update the
    syntax modules.
  [#]# 0.8.3.1 -- 2020-01-21
  * Escape `<` and `>` in latex to avoid ligatures (#91).
  * Fix and extend Idris keywords (Denis Buzdalov).
  * Update XML syntax definitions for javascript-react, qml,
    typescript, javascript, cmake, cofee, latex, perl, python,
    rest.
  * Fixed bug with context shifts using `##` syntax for foreign context.
    Previously we only handled these in IncludeRules, but
    starting with the current batches of xml files they can occur
    elsewhere too.
* Wed Nov 27 2019 psimons@suse.com
- Update skylighting to version 0.8.3.
  [#]# 0.8.3 -- 2019-11-26
  * Update XML syntax definitions for c, cmake, coffee, cpp, css,
    diff, djangotemplate, elixir, elm, glsl, haskell, html, isocpp,
    javascript-react, javascript, json, jsp, julia, latex, lua,
    markdown, matlab, mediawiki, modelines, mustache, perl, php,
    powershell, qml, rest, rust, typescript, vhdl.
  * Fix highlighting errors with non-ASCII characters in JSON (#90).
    This error was due to an optimization that made some incorrect
    assumptions.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct  4 2019 psimons@suse.com
- Update skylighting to version 0.8.2.3.
  [#]# 0.8.2.3 -- 2019-10-03
  * Tests: ensure we read test files as UTF-8.
  * Fix compiler warnings around Monoid imports.
  * Add MonadFail constraint (allowing compilation with ghc 8.8.x).
  * Add cabal.project and move CI from Travis to GitHub Actions.
* Wed Oct  2 2019 psimons@suse.com
- Update skylighting to version 0.8.2.2.
  [#]# 0.8.2.2 -- 2019-09-30
  * Remove upper bound on regex-base and require
    regex-pcre-builtin >= 0.95, to avoid a build conflict
    with earlier versions of regex-pcre-builtin and
    regex-base >= 0.94.
  * Remove unused system-pcre flag in skylighting.cabal.
    This flag only affects skylighting-core.
* Thu Sep 26 2019 psimons@suse.com
- Update skylighting to version 0.8.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-0.8.2.1/src/changelog.md
* Mon Jul 15 2019 psimons@suse.com
- Update skylighting to version 0.8.2.
  [#]# 0.8.2 -- 2019-07-14
  * Change matchRegex so it gives "no match" on a regex error
    instead of raising an exception. This seems to be how Kate
    works.  Fixes an error on long integer literals (#81).
  [#]# 0.8.1.2 -- 2019-07-14
  * Fix HlCChar for one-character octal escapes like '\0' (#82).
    Due to a bug in pCStringChar, only multi-character octal
    escapes were being recognized. This affects not just C
    highlighting, but all of the following highlighters which
    use HlCChar: fasm eiffel pike objectivec ruby vhdl scala
    java jsp nasm protobuf pure go objectivecpp gnuassembler povray
    actionscript c cs opencl boo rhtml elixir.  This fixes a
    regression introduced in version 0.3.1.
* Mon Jun 17 2019 psimons@suse.com
- Update skylighting to version 0.8.1.1.
  [#]# 0.8.1.1 -- 2019-06-13
  * Improved LaTeX escaping (#78).
* Fri Jun 14 2019 psimons@suse.com
- Update skylighting to version 0.8.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-0.8.1/src/changelog.md
* Sat Mar  2 2019 psimons@suse.com
- Update skylighting to version 0.7.7.
  [#]# 0.7.7 -- 2019-02-08
  * Depend on skylighting-core 0.7.7.x.
* Sun Feb 10 2019 psimons@suse.com
- Update skylighting to version 0.7.6.
  [#]# 0.7.6 -- 2019-02-08
  * Depend on skylighting-core 0.7.6.x.
* Sun Dec  2 2018 psimons@suse.com
- Update skylighting to version 0.7.5.
  [#]# 0.7.5 -- 2018-12-01
  * Depend on skylighting-core 0.7.5.x.
  * Add J, sml, typescript.
* Wed Oct 10 2018 psimons@suse.com
- Update skylighting to version 0.7.4.
  [#]# 0.7.4 -- 2018-10-08
  * Depend on skylighting-core 0.7.4.x.
* Thu Aug 30 2018 psimons@suse.com
- Update skylighting to version 0.7.3.
  [#]# 0.7.3 -- 2018-08-27
  * Add Sylighting.Syntax.Default and 'default' language. This
    just highlights everything as normal text.
  * Require base >= 4.8.  Drop support for ghc 7.8.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update skylighting to version 0.7.2.
  [#]# 0.7.2 -- 2018-06-08
  * Require skylighting-core >= 0.7.2.
* Mon May 14 2018 psimons@suse.com
- Update skylighting to version 0.7.1.
  * Split skylighting into skylighting-core (BSD3) and skylighting (GPL)
    (#37, Jonathan Daugherty).  skylighting-core (BSD3 licensed) includes
    the core library functionality and the source of the XML syntax, but
    not the compiled Syntax modules, and skylighting (GPL2 licensed)
    includes Syntax modules compiled from the XML syntax files.
  * We discontinue support for GHC before 7.10 (because we need to support the
    reexport-modules Cabal directive.)
  * Print message about loaded syntax defs to stderr (#36).
  * New module Skylighting.Loader, exporting
    `loadSyntaxFromFile` and `loadSyntaxesFromDir` (Jonathan Daugherty).
  * Adjust tests to load xml definitions dynamically.
  * Add ANSI color output (Alexander Ronald Altman, #22).
    + New package dependencies: `ansi-terminal` and `colour`.
    + New module: `Skylighting.Format.ANSI`, exporting `formatANSI`,
    (also reexported from the module `Skylighting`).
    + In `Skylighting.Types`, new types `ANSIColorLevel` and
    `Xterm256ColorCode`, and a new field `ansiColorLevel` in
    `FormatOptions`.
    + Main `skylighting` executable now supports ANSI output (use
    `ansi` as argument to `--format`), which is now the default output
    format. A new flag `--color-level` has been added to select
    the number of colors (with options `16`, `256`, `true`, and
    the default `auto`).
  * Reword error for missing contexts in IncludeRules.
  * Use ordNub instead of nub for missingIncludes.
  * Fixed tokenizer exceptions (#31).  Previously `throwError`
    did not actually generate `Left` results in `tokenize`,
    because of the way the MonadPlus instance worked. Rewrote
    the TokenizerM monad from scratch so that exceptions would
    not be skipped.
  * Improved error message about undefined contexts.
  * Makefile: use cabal for bootstrap target.
  * README: remove stack bootstrap instructions.
    You can no longer bootstrap with stack, because it
    insists on building ALL the executables the first time,
    and of course that can't be done with this library.
  * Use quickcheck for fuzz test.
  * Small improvements to fuzz tests in test suite.  We now
    ensure that we print the random text on test failure.  Also,
    we now run the test with many smaller samples rather than
    one big one.
  * Add aeson lower bound (because of toEncoding) (#28).
  * Fix line spacing and overflowing content in generated HTML
    (David Baynard, #25, see jgm/pandoc#4128).
    + Fix empty line height, explicitly
    + Ensure long lines scroll on screen
    + Only apply colour to the outer div
    + Don't reset line number colour
    + Fix borders on empty code lines
    + Collapse divs correctly.
  * Changes to Style types and JSON instances.  Previously we could not
    successfully round-trip through JSON.
    + `tokenStyles` is now a map rather than an association list.
    + We now use `line-number-color` instead of `line-numbers` at
    the top level in the JSON instances, falling back to
    `line-numbers` in `editor-colors`, for KDE theme compatibility.
    + We use `line-number-background-color` at the top level, falling
    back to the text background color.
    + We use `text-color` at the top level, falling back to the `text-color`
    of the `Normal` token style if it exists, for KDE compatibility.
    + We use `background-color` at the top level, falling back to
    the `background-color` in `editor-colors`, for KDE compatibility.
    + A round-trip JSON test has been added.
  * HTML formatting: fix color, bgcolor when numbering enabled.
    Previously, the code got the color and background color
    the numbers were supposed to get.  See jgm/pandoc #4103.
  * Updated syntax descriptions for bash, clojure, commonlisp, diff,
    dockerfile, doxygen, doxygenlua, fsharp, hamlet, haskell, haxe,
    java, javascript, julia, latex, literate-curry, literate-haskell,
    makefile, mediawiki, monobasic, ocaml, prolog, r, relaxng, scala,
    sci, sql-mysql, sql-postgresql, sql, xslt.
  * test program:  use --accept instead of --regen.
  * HTML formatter: always use an a element (rather than a div)
    for source lines.  The divs were invalid, because code
    elements must contain phrasing content.  Previously we used
    a elements when line anchors were called for, but there is
    no clear reason not to use them always.
  * skylighting binary: add doctype to generated HTML.
  * Fixed regression in `data-line-number` attributes in HTML
    output.  We should not include the `lineIdPrefix` in
    front of this.
  * Fixed typo in css (Artymort).
  * Fixed travis build times.
  * `FormatOptions`: added `lineIdPrefix` (jgm/pandoc#4031).
    This is needed because a web page may contain several
    code samples, and we need to make sure that the ids on
    lines are unique.
  * HTML formatter: use `lineIdPrefix` in ids for lines.
  * HTML formatter: Don't put href attributes on divs.
  * HTML output: remove outer div.  This prevented margin
    collapsing between the pre and surrounding block elements,
    and often gave us excess white space around code blocks.
    See jgm/pandoc#3996.
  * Updated XML definitions from KDE repository.
    Changed: actionscript, ada, agda, alert, alert_indent, asn1, awk, bash,
    boo, c, changelog, clojure, cmake, coldfusion, commonlisp, cpp, cs, css,
    curry, d, dockerfile, dot, doxygen, doxygenlua, eiffel, email, erlang,
    fortran, fsharp, gcc, haskell, haxe, isocpp, java, javascript, jsp, julia,
    lilypond, lua, m4, makefile, matlab, maxima, mips, modelines, modula-2,
    monobasic, objectivec, objectivecpp, ocaml, octave, opencl, pascal, perl,
    php, pike, postscript, prolog, purebasic, python, r, relaxng,
    relaxngcompact, rest, rhtml, ruby, rust, scala, scheme, sci, sql-mysql,
    sql-postgresql, sql, tcl, tcsh, verilog, vhdl, xml, xslt, xul, zsh.
  * Added support for powershell, using definition from KDE repository.
  * Stop terminating long builds on TravisCI (Kyle Ondy).
  * Removed ToJSON/FromJSON instances for KeywordAttr,
    WordSet, Matcher, Context, ContextSwitch, Rule, Syntax
    (added in 0.3.5).  Creating these increased the memory
    requirements for compiling skylighting to a degree not
    justified by the usefulness of these instances.
  * Added ToJSON/FromJSON instances for all basic types.
  * Added some background colors to 'kate' style, matching default.theme,
    and made FromJSON for Style sensitive to background-color.
  * HTML formatting: do not use `div` elements for source
    lines in inline output.
  * HTML formatting changes (David Baynard).  Note that these
    changes may require changes in hard-coded CSS that is
    used with skylighting's HTML output.
    + Wrap lines of source code in a `div` with `display` set to
    `inline-block`.  The `div`s make per-line processing easier.
    They cannot be set as `display: block` as that introduces extra
    new lines when copying and pasting.
    + Render line numbers in html using CSS pseudo elements rather than
    a table.  The line numbers are always produced, as `data-line-number`
    attributes, and css to display them as `::before` elements are
    always produced. The option to switch on line numbering only
    toggles a class; this means it is possible to toggle line numbering
    without re-running skylighting.
    + If the `linkAnchors` option is set, wrap with an `a` element rather
    than a `div`, set so that clicking the line number (and only the
    line number) will jump to that line.
    + Code wraps by default when html is printed, with wrapped lines
    indented.
  * Updated xml syntax definitions and clojure test.
  * Improved 'make update-xml' target.
  * Updated version bound for criterion.
  * Revert change from 0.3.2; now entities from a DTD are
    resolved if the DTD element is included.  This is needed
    for agda.xml and some others.  If you want to use a custom
    xml definition without needing language.dtd, just remove
    the reference to language.dtd in your xml file.
  * Added `case` keyword for ats (Hanwen (Steinway) Wu).
  * Parse xml definitions without resolving entities from
    language.dtd.  This allows xml definitions to be used even
    when language.dtd isn't available.  Existing definitions
    don't rely on the two or three entities definied in
    language.dtd, so this is harmless.
  * Small optimizations.
  * Use handwritten parser for Float instead of regex.  Fixes
    jgm/highlighting-kate#57 (again).
  * Added float parsing tests.
  * Use parsec parsers, not regex, for CStringChar and CChar.
  * Rewrote Int, Hex, Oct, CStringChar, CCHar parsers with parsec
    instead of regex.  This speeds things up.
  * Don't include leading + in Int, Hex, Oct parsers.  That gives
    bad results for things like `i+1`.
  * Store literal binary-encoded representations of the Syntax
    structure in Skylighting.Syntax.*.hs, instead of the
    structure itself.  This works around a problem ghc has
    compiling modules with large structures.  This indirect method
    produces faster compile times and avoids massive memory usage by
    ghc (especially in profiling builds).  For background see
    http://stackoverflow.com/questions/16348340/.  Closes #7.
  * Types: Internals of 'WordSet' are no longer exposed.
  * Restore Data, Typeable, Generic instances for basic types.
    To do this, we remove reCompiled field from RE (API change).  Instead, we
    have the tokenizer compile regexes the first time it encounters them,
    memoizing the results.  Performance is not significantly worse.
  * Skylighting.Syntax.*:  use string representation of the Syntax,
    which is then 'read', rather than including the code for the data
    structure directly (#7).  This indirect method produces faster compile
    times and avoids massive memory usage by ghc (especially in profiling
    builds).  For background see
    http://stackoverflow.com/questions/16348340/compiling-very-large-constants-with-ghc
  * Use -fprof-auto-exported for profiling builds.
  * Added benchmark for xml syntax definition parsing.
  * Patched perl.xml (improperly escaped regex) (#8).
    This fixes a perl regex compilation error for regex patterns
    with backslash as delimiter, e.g. m\a\.
  * Add a flag to build with system pcre (Felix Yan).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.1.1.5 with cabal2obs.
